@@ -20,6 +20,7 @@ import os
 def get_data_dir():
     """
     Returns the data directory.
+    :return: the data directory
     :rtype: str
     """
     rootdir = os.path.dirname(__file__)
@@ -31,6 +32,7 @@ def print_title(title):
     """
     Prints the title underlined.
     :param title: the title to print
+    :type title: str
     """
 
     print("\n" + title)
@@ -41,6 +43,7 @@ def print_info(info):
     """
     Prints the info.
     :param info: the info to print
+    :type info: str
     """
 
     print("\n" + info)
